@@ -50,6 +50,18 @@ class Icon(object):
         invisible menu with a default entry as special action or a full menu
         with no special way to activate the default item, and some platforms do
         not support a menu at all.
+
+    :param kwargs: Any non-standard platform dependent options. These should be
+        prefixed with the platform name thus: ``appindicator_``, ``darwin_``,
+        ``gtk_``, ``win32_`` or ``xorg_``.
+
+        Supported values are:
+
+        ``darwin_nsapplication``
+            An ``NSApplication`` instance used to run the event loop. If this
+            is not specified, the shared application will be used.
+
+            This must be specified when calling :meth:`run_detached`.
     """
     #: Whether this particular implementation has a default action that can be
     #: invoked in a special way, such as clicking on the icon.
@@ -67,7 +79,7 @@ class Icon(object):
     HAS_NOTIFICATION = True
 
     def __init__(
-            self, name, icon=None, title=None, menu=None):
+            self, name, icon=None, title=None, menu=None, **kwargs):
         self._name = name
         self._icon = icon or None
         self._title = title or ''
@@ -79,6 +91,12 @@ class Icon(object):
         self._running = False
         self.__queue = queue.Queue()
 
+        prefix = self.__class__.__module__.rsplit('.', 1)[-1][1:] + '_'
+        self._options = {
+            key[len(prefix):]: value
+            for key, value in kwargs.items()
+            if key.startswith(prefix)}
+
     def __del__(self):
         if self.visible:
             self._hide()
@@ -176,21 +194,42 @@ class Icon(object):
             thread once the loop has started. It is passed the icon as its sole
             argument.
 
-            If not specified, a simple setup function setting :attr:`visible` to
-            ``True`` is used. If you specify a custom setup function, you must
-            explicitly set this attribute.
+            If not specified, a simple setup function setting :attr:`visible`
+            to ``True`` is used. If you specify a custom setup function, you
+            must explicitly set this attribute.
         """
-        def setup_handler():
-            self.__queue.get()
-            if setup:
-                setup(self)
-            else:
-                self.visible = True
-
-        self._setup_thread = threading.Thread(target=setup_handler)
-        self._setup_thread.start()
+        self._start_setup(setup)
         self._run()
 
+    def run_detached(self, setup=None):
+        """Prepares for running the loop handling events detached.
+
+        This allows integrating *pystray* with other libraries requiring a
+        mainloop. Call this method before entering the mainloop of the other
+        library.
+
+        Depending on the backend used, calling this method may require special
+        preparations:
+
+        macOS
+            You must pass the argument ``darwin_nsapplication`` to the
+            constructor. This is to ensure that you actually have a reference
+            to the application instance used to drive the icon.
+
+        :param callable setup: An optional callback to execute in a separate
+            thread once the loop has started. It is passed the icon as its sole
+            argument.
+
+            If not specified, a simple setup function setting :attr:`visible`
+            to ``True`` is used. If you specify a custom setup function, you
+            must explicitly set this attribute.
+
+        :raises NotImplementedError: if this is not implemented for the
+            preparations taken
+        """
+        self._start_setup(setup)
+        self._run_detached()
+
     def stop(self):
         """Stops the loop handling events for the icon.
         """
@@ -247,8 +286,10 @@ class Icon(object):
         is called.
         """
         self._running = True
-        self.update_menu()
-        self.__queue.put(True)
+        try:
+            self.update_menu()
+        finally:
+            self.__queue.put(True)
 
     def _handler(self, callback):
         """Generates a callback handler.
@@ -317,6 +358,31 @@ class Icon(object):
         """
         raise NotImplementedError()
 
+    def _start_setup(self, setup):
+        """Starts the setup thread.
+
+        :param callable setup: The thread handler.
+        """
+        def setup_handler():
+            self.__queue.get()
+            if setup:
+                setup(self)
+            else:
+                self.visible = True
+
+        self._setup_thread = threading.Thread(target=setup_handler)
+        self._setup_thread.start()
+
+    def _run_detached(self):
+        """Runs detached.
+
+        This method must call :meth:`_mark_ready` once ready.
+
+        This is a platform dependent implementation.
+        """
+        # By default, we assume that we can simply delegate to a thread
+        threading.Thread(target=lambda: self.run(setup)).start()
+
     def _stop(self):
         """Stops the event loop.
 
@@ -384,8 +450,8 @@ class MenuItem(object):
         """Whether this item is checked.
 
         This can be either ``True``, which implies that the item is checkable
-        and checked, ``False``, which implies that the item is checkable but not
-        checked, and ``None`` for uncheckable items.
+        and checked, ``False``, which implies that the item is checkable but
+        not checked, and ``None`` for uncheckable items.
 
         Depending on platform, uncheckable items may be rendered differently
         from unchecked items.
@@ -396,8 +462,8 @@ class MenuItem(object):
     def radio(self):
         """Whether this item is a radio button.
 
-        This is only used for checkable items. It is always set to ``False`` for
-        uncheckable items.
+        This is only used for checkable items. It is always set to ``False``
+        for uncheckable items.
         """
         if self.checked is not None:
             return self._radio(self)
@@ -442,8 +508,8 @@ class MenuItem(object):
             less than the expected number of arguments, a wrapper will be
             returned.
 
-        :raises ValueError: if ``action`` requires more than the expected number
-            of arguments
+        :raises ValueError: if ``action`` requires more than the expected
+            number of arguments
 
         :return: a callable
         """
