@@ -46,12 +46,26 @@ class Icon(_base.Icon):
     def __init__(self, *args, **kwargs):
         super(Icon, self).__init__(*args, **kwargs)
 
-        #: The icon delegate
-        self._delegate = None
-
         #: The NSImage version of the icon
         self._icon_image = None
 
+        #: The NSApplication managing this icon
+        self._app = self._options['nsapplication'] \
+            if 'nsapplication' in self._options \
+            else AppKit.NSApplication.sharedApplication()
+        self._detachable = 'nsapplication' in self._options
+
+        #: The icon delegate
+        self._delegate = IconDelegate.alloc().init()
+        self._delegate.icon = self
+
+        self._status_bar = AppKit.NSStatusBar.systemStatusBar()
+        self._status_item = self._status_bar.statusItemWithLength_(
+            AppKit.NSVariableStatusItemLength)
+
+        self._status_item.button().setTarget_(self._delegate)
+        self._status_item.button().setAction_(self._ACTION_SELECTOR)
+
     def _show(self):
         self._assert_image()
         self._update_title()
@@ -82,20 +96,6 @@ class Icon(_base.Icon):
             self._menu_handle = None
 
     def _run(self):
-        # Make sure there is an NSApplication instance
-        self._app = AppKit.NSApplication.sharedApplication()
-
-        # Make sure we have a delegate to handle the action events
-        self._delegate = IconDelegate.alloc().init()
-        self._delegate.icon = self
-
-        self._status_bar = AppKit.NSStatusBar.systemStatusBar()
-        self._status_item = self._status_bar.statusItemWithLength_(
-            AppKit.NSVariableStatusItemLength)
-
-        self._status_item.button().setTarget_(self._delegate)
-        self._status_item.button().setAction_(self._ACTION_SELECTOR)
-
         # Notify the setup callback
         self._mark_ready()
 
@@ -117,6 +117,12 @@ class Icon(_base.Icon):
                 PyObjCTools.MachSignals.signal(signal.SIGINT, previous_sigint)
             self._status_bar.removeStatusItem_(self._status_item)
 
+    def _run_detached(self):
+        if self._detachable:
+            self._mark_ready()
+        else:
+            raise NotImplementedError()
+
     def _stop(self):
         self._app.stop_(self._app)
 
@@ -185,7 +191,7 @@ class Icon(_base.Icon):
 
         :return: a menu
         """
-        if not descriptors or self._delegate is None:
+        if not descriptors:
             return None
 
         else:
@@ -202,8 +208,8 @@ class Icon(_base.Icon):
             return nsmenu
 
     def _create_menu_item(self, descriptor, callbacks):
-        """Creates a :class:`AppKit.NSMenuItem` from a :class:`pystray.MenuItem`
-        instance.
+        """Creates a :class:`AppKit.NSMenuItem` from a
+        :class:`pystray.MenuItem` instance.
 
         :param descriptor: The menu item descriptor.
 
