@@ -31,6 +31,7 @@ class Icon(_base.Icon):
     def __init__(self, *args, **kwargs):
         super(Icon, self).__init__(*args, **kwargs)
 
+        self._atom = self._register_class()
         self._icon_handle = None
         self._hwnd = None
         self._menu_hwnd = None
@@ -45,17 +46,6 @@ class Icon(_base.Icon):
 
         self._queue = queue.Queue()
 
-        # Create the message loop
-        msg = wintypes.MSG()
-        lpmsg = ctypes.byref(msg)
-        win32.PeekMessage(
-            lpmsg, None, win32.WM_USER, win32.WM_USER, win32.PM_NOREMOVE)
-
-        self._atom = self._register_class()
-        self._hwnd = self._create_window(self._atom)
-        self._menu_hwnd = self._create_window(self._atom)
-        self._HWND_TO_ICON[self._hwnd] = self
-
     def __del__(self):
         if self._running:
             self._stop()
@@ -120,6 +110,16 @@ class Icon(_base.Icon):
             self._menu_handle = None
 
     def _run(self):
+        # Create the message loop
+        msg = wintypes.MSG()
+        lpmsg = ctypes.byref(msg)
+        win32.PeekMessage(
+            lpmsg, None, win32.WM_USER, win32.WM_USER, win32.PM_NOREMOVE)
+
+        self._hwnd = self._create_window(self._atom)
+        self._menu_hwnd = self._create_window(self._atom)
+        self._HWND_TO_ICON[self._hwnd] = self
+
         self._mark_ready()
 
         # Run the event loop
@@ -238,22 +238,22 @@ class Icon(_base.Icon):
             win32.GetModuleHandle(None),
             None)
 
-        # On Vista+, we must explicitly opt-in to receive WM_TASKBARCREATED when
-        # running with escalated privileges
+        # On Vista+, we must explicitly opt-in to receive WM_TASKBARCREATED
+        # when running with escalated privileges
         win32.ChangeWindowMessageFilterEx(
             hwnd, win32.WM_TASKBARCREATED, win32.MSGFLT_ALLOW, None)
         return hwnd
 
     def _create_menu(self, descriptors, callbacks):
-        """Creates a :class:`ctypes.wintypes.HMENU` from a :class:`pystray.Menu`
-        instance.
+        """Creates a :class:`ctypes.wintypes.HMENU` from a
+        :class:`pystray.Menu` instance.
 
         :param descriptors: The menu descriptors. If this is falsy, ``None`` is
             returned.
 
         :param callbacks: A list to which a callback is appended for every menu
-            item created. The menu item IDs correspond to the items in this list
-            plus one.
+            item created. The menu item IDs correspond to the items in this
+            list plus one.
 
         :return: a menu
         """
@@ -265,7 +265,7 @@ class Icon(_base.Icon):
             hmenu = win32.CreatePopupMenu()
             for i, descriptor in enumerate(descriptors):
                 # Append the callbacks before creating the menu items to ensure
-                # that the first item get the ID 1
+                # that the first item gets the ID 1
                 callbacks.append(self._handler(descriptor))
                 menu_item = self._create_menu_item(descriptor, callbacks)
                 win32.InsertMenuItem(hmenu, i, True, ctypes.byref(menu_item))
@@ -279,8 +279,8 @@ class Icon(_base.Icon):
         :param descriptor: The menu item descriptor.
 
         :param callbacks: A list to which a callback is appended for every menu
-            item created. The menu item IDs correspond to the items in this list
-            plus one.
+            item created. The menu item IDs correspond to the items in this
+            list plus one.
 
         :return: a :class:`pystray._util.win32.MENUITEMINFO`
         """
